@@ -2,7 +2,7 @@
   filterkmail_maildir.h  -  Kmail maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,8 @@
 #define MAILIMPORTER_FILTER_KMAIL_MAILDIR_H
 
 #include "filters.h"
-namespace MailImporter {
+namespace MailImporter
+{
 class FilterKMail_maildirPrivate;
 /**
  * Imports KMail mail folder with maildir format recursively, recreating the folder structure.
