@@ -1,25 +1,16 @@
 /*
-  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MAILIMPORTER_UTILS_H
 #define MAILIMPORTER_UTILS_H
 
-namespace MailImporter {
+#include <QString>
+
+namespace MailImporter
+{
 /**
  * Glorified QString[N] for (a) understandability (b) older gcc compatibility.
  */
@@ -53,7 +44,7 @@ public:
     /** Assignment operator. Does the same thing as
      *   the copy constructor.
      */
-    FolderStructureBase &operator =(const FolderStructureBase &s)
+    FolderStructureBase &operator=(const FolderStructureBase &s)
     {
         for (unsigned int i = 0; i < size; i++) {
             d[i] = s[i];
@@ -64,7 +55,7 @@ public:
     /** Access the different fields. There doesn't seem to
      *   be a real semantics for the fields.
      */
-    const QString operator [](unsigned int i) const
+    const QString operator[](unsigned int i) const
     {
         if (i < size) {
             return d[i];
@@ -74,7 +65,7 @@ public:
     }
 
     /** Access the different fields, for writing. */
-    QString &operator [](unsigned int i)
+    QString &operator[](unsigned int i)
     {
         Q_ASSERT(i < size);
         if (i < size) {
