@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ SelectThunderbirdProfileDialog::SelectThunderbirdProfileDialog(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Select thunderbird profile"));
     setModal(true);
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
     mSelectProfile = new SelectThunderbirdProfileWidget(this);
     mSelectProfile->setObjectName(QStringLiteral("selectprofile"));
